@@ -3,8 +3,8 @@ from PyQt5.QtWidgets import QWidget, QCheckBox, QHBoxLayout
 
 from feeluown.utils.reader import wrap
 from feeluown.models import SearchType
-from feeluown.widgets.tabbar import Tab
-from feeluown.widgets.magicbox import KeySourceIn, KeyType
+from feeluown.gui.widgets.tabbar import Tab
+from feeluown.gui.widgets.magicbox import KeySourceIn, KeyType
 from feeluown.gui.page_containers.table import Renderer
 from feeluown.gui.base_renderer import LibraryTabRendererMixin
 
